<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs_CZ">
<context>
    <name>OutputWaveOutFactory</name>
    <message>
        <location filename="../outputwaveoutfactory.cpp" line="30"/>
        <source>WaveOut Plugin</source>
        <translation>Modul WaveOut</translation>
    </message>
    <message>
        <location filename="../outputwaveoutfactory.cpp" line="54"/>
        <source>About WaveOut Output Plugin</source>
        <translation>O výstupním modulu WaveOut</translation>
    </message>
    <message>
        <location filename="../outputwaveoutfactory.cpp" line="55"/>
        <source>Qmmp WaveOut Output Plugin</source>
        <translation>Výstupní modul Qmmp WaveOut</translation>
    </message>
    <message>
        <location filename="../outputwaveoutfactory.cpp" line="56"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilja Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../outputwaveoutfactory.cpp" line="57"/>
        <source>Based on aacDECdrop player</source>
        <translation>Založeno na přehrávači aacDECdrop</translation>
    </message>
</context>
</TS>
